.. s2spy documentation master file, created by
   sphinx-quickstart on Wed May  5 22:45:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
  :maxdepth: 2
  :caption: Contents:
  :hidden:

  Readme <readme_link>
  Developer Readme <README.dev.md>
  Contribution guide <CONTRIBUTING.md>
  Changelog <changelog_link>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
